From 999bfd27be3f33d2aa9fab8166e6d0c7240f4447 Mon Sep 17 00:00:00 2001
From: Eleni Mathioulaki <emathioulaki@athenarc.gr>
Date: Fri, 28 Feb 2025 13:58:58 +0000
Subject: [PATCH] feat(py-ray): add version 2.30.0

---
 packages/py-ray/package.py | 23 ++++++++++++++---------
 1 file changed, 14 insertions(+), 9 deletions(-)

diff --git a/packages/py-ray/package.py b/packages/py-ray/package.py
index 82ba34c4..f1bf4b72 100644
--- a/packages/py-ray/package.py
+++ b/packages/py-ray/package.py
@@ -15,7 +15,10 @@ class PyRay(PythonPackage):
 
     license("Apache-2.0")
 
-    # begin EBRAINS (added): ECM new node-js -> new react whatever -> new py-ray
+    # begin EBRAINS (added): new versions
+    # new version to allow building with newer bazel
+    version("2.30.0", sha256="854d549a77f0b0e810d1e9a18e7becf984279e2a0bfad5bed508f500ff770e34")
+    # ECM: new node-js -> new react whatever -> new py-ray
     version("2.4.0", sha256="b0110a84630b2f6d10cd13e8ac955875c3658373eb6cabcc77cf316de3c28066")
     # end EBRAINS
     version("2.0.1", sha256="b8b2f0a99d2ac4c001ff11c78b4521b217e2a02df95fb6270fd621412143f28b")
@@ -30,18 +33,20 @@ class PyRay(PythonPackage):
     conflicts("node-js@17:", when="@:2.0.1")
     # end EBRAINS
 
-    # begin EBRAINS (added): ElM add missing dependencies/constraints for added version 2.4.0
+    # begin EBRAINS (added): ElM add missing dependencies/constraints for added versions
+    depends_on("python@3.9:3.12", when="@2.30.0", type=("build", "run"))
     depends_on("python@3.6:3.11", when="@2.4.0", type=("build", "run"))
+    depends_on("bazel@6.5", when="@2.30.0", type="build")
     depends_on("bazel@5", when="@2.4.0", type="build")
-    depends_on("py-cython@0.29.32:", when="@2.4.0", type="build")
+    depends_on("py-cython@0.29.32:", when="@2.4.0:", type="build")
     depends_on("py-attrs", when="@2.4.0", type=("build", "run"))
-    depends_on("py-click@7.0:", when="@2.4.0", type=("build", "run"))
-    depends_on("py-grpcio@1.32:1.51.3", when="@2.4.0 ^python@:3.9", type=("build", "run"))
-    depends_on("py-grpcio@1.42:1.51.3", when="@2.4.0 ^python@3.10:", type=("build", "run"))
-    depends_on("py-protobuf@3.15.3:", when="@2.4.0", type=("build", "run"))
+    depends_on("py-click@7.0:", when="@2.4.0:", type=("build", "run"))
+    depends_on("py-grpcio@1.32:1.51.3", when="@2.4.0: ^python@:3.9", type=("build", "run"))
+    depends_on("py-grpcio@1.42:1.51.3", when="@2.4.0: ^python@3.10:", type=("build", "run"))
+    depends_on("py-protobuf@3.15.3:", when="@2.4.0:", type=("build", "run"))
     depends_on("py-frozenlist", when="@2.4.0", type=("build", "run"))
     depends_on("py-typing-extensions", when="@2.4.0 ^python@:3.7", type=("build", "run"))
-    depends_on("py-virtualenv@20.0.24:", when="@2.4.0", type=("build", "run"))
+    depends_on("py-virtualenv@20.0.24:", when="@2.4.0:", type=("build", "run"))
     # end EBRAINS
 
     depends_on("python@3.6:3.10", when="@2.0.1", type=("build", "run"))
@@ -113,7 +118,7 @@ class PyRay(PythonPackage):
     build_directory = "python"
 
     # begin EBRAINS (added): fix boost download url
-    patch("fix-url-boost.patch", when="@2.4.0:")
+    patch("fix-url-boost.patch", when="@2.4.0")
     # end EBRAINS
 
     def patch(self):
-- 
GitLab